@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_tree.py 11930 2020-02-18 16:03:26Z Lavender $
+# $Id: build_tree.py 13369 2022-01-08 11:52:12Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-19 00:03:26 +0800 (週三, 19 二月 2020) $
-# $Revision: 11930 $
+# $Date: 2022-01-08 19:52:12 +0800 (週六, 08 一月 2022) $
+# $Revision: 13369 $
 
 import os
 
@@ -23,7 +23,7 @@ from django.core.management.base import BaseCommand
 
 from Iuno.template_editor.models import Static, Template, FOLDER, FILE
 from Iuno.template_editor.admin import checkVersion
-from Iuno.template_editor import TEMPLATE_DIR, STATIC_DIR, BACKUP_FILE_DIR
+from Iuno.template_editor import TEMPLATE_DIRS, STATIC_DIR, BACKUP_FILE_DIR
 
 class Command(BaseCommand):
 
@@ -33,7 +33,7 @@ class Command(BaseCommand):
         Template.objects.all().delete()
 
         self.staticPath = STATIC_DIR
-        self.templatePath = TEMPLATE_DIR
+        self.templatePaths = TEMPLATE_DIRS
 
         self.staticDirs = None
         if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_STATIC'):
@@ -50,7 +50,8 @@ class Command(BaseCommand):
             self.templateDirs = settings.TEMPLATE_EDITOR_PUBLIC_TEMPLATES
 
         self.createNode(self.staticPath, Static)
-        self.createNode(self.templatePath, Template)
+        for templatePath in self.templatePaths:
+            self.createNode(templatePath, Template)
 
     @transaction.atomic
     def createNode(self, path, model, parent=None):
@@ -77,6 +78,18 @@ class Command(BaseCommand):
                             create = True
             else:
                 create = True
+                
+            if parent:
+                rootPath = parent.rootPath
+            else:
+                rootPath = path
+                # 做根目錄 node
+                parent = model.objects.create(
+                    type=FOLDER,
+                    name=path,
+                    parent=None,
+                    rootPath=path,
+                )
 
             if os.path.isfile(filePath):
                 if create:
@@ -84,7 +97,8 @@ class Command(BaseCommand):
                     node = model.objects.create(
                         type=FILE,
                         name=f,
-                        parent=parent
+                        parent=parent,
+                        rootPath=rootPath,
                     )
             else:
                 if create:
@@ -92,7 +106,8 @@ class Command(BaseCommand):
                     node = model.objects.create(
                         type=FOLDER,
                         name=f,
-                        parent=parent
+                        parent=parent,
+                        rootPath=rootPath,
                     )
                     self.createNode(filePath, model, parent=node)
          
