@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11930 2020-02-18 16:03:26Z Lavender $
+# $Id: models.py 13369 2022-01-08 11:52:12Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-02-19 00:03:26 +0800 (Wed, 19 Feb 2020) $
-# $Revision: 11930 $
+# $Date: 2022-01-08 19:52:12 +0800 (週六, 08 一月 2022) $
+# $Revision: 13369 $
 
 import os
 import hashlib
@@ -26,7 +26,7 @@ from django.db.models import Max
 from mptt.models import MPTTModel, TreeForeignKey
 
 from Iuno.template_editor import (
-    BACKUP_DIR_NAME, BACKUP_FILE_DIR, STATIC_DIR, TEMPLATE_DIR, toBytes)
+    BACKUP_DIR_NAME, BACKUP_FILE_DIR, STATIC_DIR, TEMPLATE_DIRS, toBytes)
 
 FOLDER = 1
 FILE = 2
@@ -102,13 +102,14 @@ class VersionControlMixin(object):
 
 class Static(MPTTModel, VersionControlMixin):
     type = models.IntegerField(choices=TYPE_CHOICES)
-    name = models.CharField(max_length=256)
+    name = models.CharField(max_length=1024)
     parent = TreeForeignKey(
         'self', 
         on_delete=models.CASCADE, 
         null=True, 
         blank=True, 
         related_name='children')
+    rootPath = models.CharField(max_length=1024, null=True, default=None)
 
     class MPTTMeta:
         order_insertion_by = ['name']
@@ -119,7 +120,8 @@ class Static(MPTTModel, VersionControlMixin):
 
         ancestors = self.get_ancestors()
         for ancestor in ancestors:
-            path = os.path.join(path, ancestor.name)
+            if ancestor.parent:
+                path = os.path.join(path, ancestor.name)
         path = os.path.join(path, self.name)
 
         return path
@@ -129,7 +131,7 @@ class Static(MPTTModel, VersionControlMixin):
         path = self.path
         
         # FIXME: deploy maybe unwork. 
-        fullPath = os.path.join(STATIC_DIR, path)
+        fullPath = os.path.join(self.rootPath, path)
 
         return fullPath
 
@@ -148,13 +150,14 @@ class Static(MPTTModel, VersionControlMixin):
 
 class Template(MPTTModel, VersionControlMixin):
     type = models.IntegerField(choices=TYPE_CHOICES)
-    name = models.CharField(max_length=256)
+    name = models.CharField(max_length=1024)
     parent = TreeForeignKey(
         'self', 
         on_delete=models.CASCADE, 
         null=True, 
         blank=True, 
         related_name='children')
+    rootPath = models.CharField(max_length=1024, null=True, default=None)
 
     class MPTTMeta:
         order_insertion_by = ['name']
@@ -165,7 +168,8 @@ class Template(MPTTModel, VersionControlMixin):
 
         ancestors = self.get_ancestors()
         for ancestor in ancestors:
-            path = os.path.join(path, ancestor.name)
+            if ancestor.parent:
+                path = os.path.join(path, ancestor.name)
         path = os.path.join(path, self.name)
 
         return path
@@ -175,7 +179,7 @@ class Template(MPTTModel, VersionControlMixin):
         path = self.path
         
         # FIXME: settings.TEMPLATES[0]['DIRS'][0] maybe undefined
-        fullPath = os.path.join(TEMPLATE_DIR, path)
+        fullPath = os.path.join(self.rootPath, path)
         
         return fullPath
 
